@@ -30,6 +30,7 @@ import meshio
 from ..Geometry import GeometricObjects as geomObj                              # classes for implemented geometric objects
 from ..Visualization.GeometryVisualization import GeometryVisualization, PYTHONOCC_AVAILABLE   # class for geometry visualization
 from ..Visualization.MeshVisualization import MeshVisualization                 # class for mesh visualization
+from ..MeshExport import FeapExport
 
 
 #############################
@@ -121,7 +122,8 @@ class GenericModel:
         # initialize Gmsh-Python-API
         self.gmshConfigChanges={                                                # default Gmsh configuration changes
             "General.Terminal": 0,                                              # deactivate console output by default (only activated for mesh generation)
-            "Mesh.CharacteristicLengthExtendFromBoundary": 0,                   # do not calculate mesh sizes from the boundary by default (since mesh sizes are specified by fields)
+            "Geometry.OCCBoundsUseStl": 1,                                      # use more accurate computation of bounding boxes (slower but advantegous for periodicity constraints)
+            "Geometry.Tolerance": 1e-12                                         # adjust geometric tolerance to be a little more precise then default (1e-8)
         }
         self.gmshAPI=self.initializeGmsh(gmshConfigChanges)                     # this assignment facilitates the usage of all methods provided by the gmsh.model class
 
@@ -284,8 +286,10 @@ class GenericModel:
 
         # create mesh file depending on the chosen file extension
         os.makedirs(fileDir,exist_ok=True)                                      # ensure that the file directory exists
-        if fileExt == ".msh":                                                   # file extension is "".msh"
+        if fileExt == ".msh":                                                   # file extension is ".msh"
             gmsh.write(fileDir+"/"+fileName+fileExt)                            # -> save mesh using built-in gmsh.write method
+        elif fileExt == ".feap":                                                # file extension is ".feap" -> write feap mesh files
+            FeapExport(self)
         else:                                                                   # file extension is different from ".msh"
             if fileExt in SUPPORTED_MESH_FORMATS:                               # -> check if file extension is supported by meshio
                 with tf.TemporaryDirectory() as tmpDir:                         # ->-> create temporary directory
