@@ -10,12 +10,14 @@ from gmshModel._version import __version__
 # import modules
 from . import (
     Geometry,
+    MeshExport,
     Model,
     Visualization,
 )
 
 # decide what happens for "from gmshModel import *"
 __all__=["Geometry",
+         "MeshExport",
          "Model",
          "Visualization",
          "__version__"]
